@@ -1,6 +1,6 @@
 def validate_triad_var_name(expr: str) -> bool:
     """Check if `expr` is a valid Triad variable name based on Triad standard:
-    it has to be a valid python identifier and it can't be purly `_`
+    it has to be a valid python identifier and it can't be purely `_`
 
     :param expr: column name expression
     :return: whether it is valid
@@ -12,7 +12,7 @@ def validate_triad_var_name(expr: str) -> bool:
 
 def assert_triad_var_name(expr: str) -> str:
     """Check if `expr` is a valid Triad variable name based on Triad standard:
-    it has to be a valid python identifier and it can't be purly `_`
+    it has to be a valid python identifier and it can't be purely `_`
 
     :param expr: column name expression
     :raises AssertionError: if the expression is invalid
